@@ -1,42 +1,64 @@
 import pickle
 import pickletools
 import zlib
+from functools import lru_cache
 from pathlib import Path
 from typing import Dict, List, Optional
 
+from anyio import open_file
+
+from ..exceptions import AccountAlreadyExists
+from ..plugin_config import AccountConfig
 from ..plugin_config import config as plugin_config
-from .models import ProcessAccount
+from .models import ProcessAccountsStore
 from .process import GoCQProcess
 
 
 class ProcessesManager:
     _processes: Dict[int, GoCQProcess] = {}
 
+    @staticmethod
+    @lru_cache
+    def is_predefined(uin: int) -> Optional[AccountConfig]:
+        account = next(
+            (account for account in plugin_config.ACCOUNTS if account.uin == uin), None
+        )
+        return account
+
     get = _processes.get
 
     @classmethod
     def add(cls, process: GoCQProcess, uin: Optional[int] = None):
         uin = uin or process.account.uin
         if uin in cls._processes:
-            raise ValueError(f"Account {process.account.uin} is already initialized.")
+            raise AccountAlreadyExists
         cls._processes[uin] = process
 
     @classmethod
-    def create(cls, account: ProcessAccount):
+    def create(cls, account: AccountConfig):
         return GoCQProcess(account, **plugin_config.PROCESS_KWARGS)
 
+    @classmethod
+    async def remove(cls, uin: int):
+        process = cls._processes.pop(uin)
+        process.log_listeners.clear()
+        await process.stop()
+        return
+
     @classmethod
     def all(cls) -> List[GoCQProcess]:
         return [*cls._processes.copy().values()]
 
     @classmethod
-    def save(cls, save_path: Path) -> int:
-        accounts = [process.account for process in cls.all()]
-        dumped = pickle.dumps(accounts)
+    async def save(cls, save_path: Path) -> int:
+        store = ProcessAccountsStore(
+            accounts=[process.account.source for process in cls.all()]
+        )
+        dumped = pickle.dumps(store)
         dumped = pickletools.optimize(dumped)
         compressed = zlib.compress(dumped, level=zlib.Z_BEST_COMPRESSION)
-        with open(save_path, "wb") as f:
-            size = f.write(compressed)
+        async with await open_file(save_path, "wb") as f:
+            size = await f.write(compressed)
         return size
 
     @classmethod
@@ -48,15 +70,19 @@ class ProcessesManager:
         ]
 
     @classmethod
-    def load_saved(
+    async def load_saved(
         cls, save_path: Path, *, ignore_loaded: bool = False
     ) -> List[GoCQProcess]:
-        with open(save_path, "rb") as f:
-            compressed = f.read()
+        async with await open_file(save_path, "rb") as f:
+            compressed = await f.read()
         decompressed = zlib.decompress(compressed)
-        accounts: List[ProcessAccount] = pickle.loads(decompressed)
+        store: ProcessAccountsStore = pickle.loads(decompressed)
         return [
             GoCQProcess(account, **plugin_config.PROCESS_KWARGS)
-            for account in accounts
-            if not ignore_loaded or account.uin not in cls._processes
+            for account in store.accounts
+            if (
+                not cls.is_predefined(account.uin)
+                or not ignore_loaded
+                or account.uin not in cls._processes
+            )
         ]
