@@ -1,16 +1,19 @@
 import asyncio
+import mimetypes
 import re
 import subprocess
 import threading
+from base64 import b64encode
 from itertools import count
 from time import sleep
-from typing import Any, Awaitable, Callable, Dict, List, Optional, Set, TypeVar, Union
+from typing import Any, Awaitable, Callable, Dict, List, Optional, Set, TypeVar
 
 import psutil
 from nonebot.utils import escape_tag, run_sync
 
 from ..log import logger
 from ..plugin_config import AccountConfig
+from ..exceptions import ProcessAlreadyStarted, ProcessNotStarted
 from .config import generate_config, generate_device
 from .download import ACCOUNTS_DATA_PATH, BINARY_PATH
 from .models import (
@@ -59,10 +62,11 @@ class LogStorage:
 class GoCQProcess:
     process: Optional[subprocess.Popen] = None
     daemon_thread: Optional[threading.Thread] = None
+    daemon_thread_running = False
 
     def __init__(
         self,
-        account: Union[AccountConfig, ProcessAccount],
+        account: AccountConfig,
         *,
         kill_timeout: float = 5,
         stop_timeout: float = 6,
@@ -78,15 +82,12 @@ class GoCQProcess:
         self.cwd = ACCOUNTS_DATA_PATH / str(account.uin)
         self.cwd.mkdir(parents=True, exist_ok=True)
 
-        self.account = (
-            ProcessAccount(
-                uin=account.uin,
-                password=account.password,  # type:ignore
-                config=generate_config(account, self.cwd),
-                device=generate_device(account, self.cwd),
-            )
-            if not isinstance(account, ProcessAccount)
-            else account
+        self.account = ProcessAccount(
+            source=account,
+            uin=account.uin,
+            password=account.password,  # type:ignore
+            config=generate_config(account, self.cwd),
+            device=generate_device(account, self.cwd),
         )
 
         self.loop = asyncio.get_running_loop()
@@ -145,6 +146,9 @@ class GoCQProcess:
 
     @run_sync
     def start(self):
+        if self.daemon_thread_running:
+            raise ProcessAlreadyStarted
+
         def runner():
             for restarted in count():
                 if not self.daemon_thread_running:
@@ -172,6 +176,9 @@ class GoCQProcess:
         self.daemon_thread.name = f"daemon-thread-{self.account.uin}"
         self.daemon_thread.start()
 
+        sleep(self.restart_interval)
+        return
+
     @run_sync
     def stop(self):
         self.daemon_thread_running = False
@@ -184,7 +191,16 @@ class GoCQProcess:
     @run_sync
     def status(self) -> ProcessInfo:
         if self.process is None:
-            raise RuntimeError("Process not started yet.")
+            raise ProcessNotStarted
+
+        qr_path = self.cwd / "qrcode.png"
+        if qr_path.exists():
+            mimetype, _ = mimetypes.guess_type(qr_path)
+            qr_data = qr_path.read_bytes()
+            qr_uri = f"data:{mimetype};base64,{b64encode(qr_data).decode()}"
+        else:
+            qr_uri = None
+
         if self.process.returncode is None:
             process = psutil.Process(self.process.pid)
             with process.oneshot():
@@ -196,11 +212,11 @@ class GoCQProcess:
                 status=ProcessStatus.running,
                 total_logs=self.logs.count,
                 restarts=self.restart_count,
+                qr_uri=qr_uri,
                 details=RunningProcessDetail(
                     pid=self.process.pid,
                     status=status,
                     memory_used=memory.rss,
-                    swap_used=memory.vms,
                     cpu_percent=cpu,
                     start_time=create_time,
                 ),
